<?php
/*
Plugin Name: HitCount
Description: Counts page hits and visitors
Version: 1.0
Author: Martin Vlcek
Author URI: http://mvlcek.bplaced.net

Public functions:
	return_hitcount_hits($slug)
		returns the hits for the page identified by $slug, normally return_page_slug()
	return_hitcount_visits()
		returns the number of visits to the site
*/

# get correct id for plugin
$thisfile = basename(__FILE__, ".php");

define('HITCOUNT_DIR', 'hitcount/'); 

# register plugin
register_plugin(
	$thisfile, 
	'HitCount', 	
	'1.0', 		
	'Martin Vlcek',
	'http://mvlcek.bplaced.net', 
	'Counts page hits and visitors',
	'support',
	'hitcount_overview'  
);

# FRONTEND
add_action('index-pretemplate', 'hitcount_init_page');
add_action('pre-download', 'hitcount_init_download');  # requires Download Interceptor plugin

# BACKEND
add_action('support-sidebar', 'createSideMenu', array($thisfile, 'Hits & Visitors'));


# ===== FRONTEND HOOKS =====

function hitcount_init_page() {
  global $url;
  hitcount_init($url);
}

function hitcount_init_download() {
  global $file;
  hitcount_init(substr($file,strlen(GSDATAUPLOADPATH)));
}


# ===== FRONTEND FUNCTIONS =====

function return_hitcount_hits($slugOrFile) {
  $hits = @file(GSDATAOTHERPATH . HITCOUNT_DIR . 'hits_' . preg_replace('/[^A-Za-z0-9-]+/','_',$slugOrFile) . '.txt');
	return $hits ? $hits[0] : 0;
}

function return_hitcount_visits() {
	$visits = @file(GSDATAOTHERPATH . HITCOUNT_DIR . 'visits.txt');
	return $visits ? $visits[0] : 0;
}


# ===== BACKEND PAGES =====

function hitcount_overview() {
  require_once(GSPLUGINPATH.'hitcount/backend.php');
  hitcount_overview_impl();
}


# ===== OTHER FUNCTIONS =====

function hitcount_init($slugOrFile) {
  $hcdir = GSDATAOTHERPATH . HITCOUNT_DIR;
  if (!file_exists($hcdir)) {
    mkdir(substr($hcdir,0,strlen($hcdir)-1), 0777);
    $fp = fopen($hcdir . '.htaccess', 'w');
    fputs($fp, 'Deny from all');
    fclose($fp);
  }
  @session_start();
  $lp = fopen(GSDATAOTHERPATH . HITCOUNT_DIR . 'lock.txt', 'w');
  if (flock($lp, LOCK_EX)) {
    # visitors
    if (!isset($_SESSION['hitcount_visits'])) {
      $_SESSION['hitcount_visits'] = hitcount_count($hcdir . 'visits.txt');
    }
    # hits
    hitcount_count($hcdir . 'hits_' . preg_replace('/[^A-Za-z0-9\.-]+/','_',$slugOrFile) . '.txt');
    # log
    $fp = fopen(GSDATAOTHERPATH . HITCOUNT_DIR . 'log.txt', 'a');
    $referer = @$_SERVER["HTTP_REFERER"];
    $useragent = @$_SERVER["HTTP_USER_AGENT"];
    fputs($fp, time() . " " . $_SESSION['hitcount_visits'] . " " . preg_replace('/\s+/','_',$slugOrFile) . " " . $referer . " " . $useragent . "\n");
    fclose($fp);
    flock($lp, LOCK_UN);
  }
  fclose($lp);
}

function hitcount_count($hcfile) {
  if (file_exists($hcfile)) {
    $hits = file($hcfile);
    $hits = $hits[0] + 1;
  } else {
    $hits = 1;
  }
  $fp = fopen($hcfile, 'w');
  fputs($fp, $hits);
  fclose($fp);
  return $hits;
}

function hitcount_reset() {
  $dir_handle = @opendir(GSDATAOTHERPATH . HITCOUNT_DIR) or die("Unable to open hitcount directory");
  while ($filename = readdir($dir_handle)) {
    if (!is_dir(GSDATAOTHERPATH . HITCOUNT_DIR . $filename) && $filename != '.htaccess') {
      unlink(GSDATAOTHERPATH . HITCOUNT_DIR . $filename);
    }
  }
}


